@@ -1,5 +1,5 @@
 package Apache::Queue;
-$VERSION = 0.3.1;
+
 use strict;
 use Apache::Constants qw( :response :methods :http );
 use Apache::File;
@@ -13,15 +13,14 @@ use vars qw( @sends @queue $r $template );
 sub handler {
   $r         = shift;
   my $status = OK;
-  my ($found, $x, $pos );
+  my ($found, $x, $pos, $status);
   my $host = $r->get_remote_host;
 
   my $max_sends  = $r->dir_config("MaxSends") || 10;
   my $queue_size = $r->dir_config("QueueSize") || 300;
-  my $tmpdir = $r->dir_config("QueuePath") || "/tmp";
 
-  my $s = tie @sends, 'DB_File', "$tmpdir/apache_queue-sends", O_RDWR|O_CREAT, 0666, $DB_RECNO;
-  my $q = tie @queue, 'DB_File', "$tmpdir/apache_queue-queue", O_RDWR|O_CREAT, 0666, $DB_RECNO;
+  my $s = tie @sends, 'DB_File', '/tmp/apache_queue-sends', O_RDWR|O_CREAT, 0666, $DB_RECNO;
+  my $q = tie @queue, 'DB_File', '/tmp/apache_queue-queue', O_RDWR|O_CREAT, 0666, $DB_RECNO;
 
   my $now = time;
   @sends = grep { $now-$_ < 300 } @sends;
@@ -292,38 +291,33 @@ Apache::Queue - An HTTP file queueing system.
 
 =head1 SYNOPSIS
 
-  #httpd.conf
-  <Directory "/usr/local/apache/htdocs/files">
-    SetHandler perl-script
-    PerlHandler Apache::Queue
-    
-    # the size of the queue (default: 300)
-    PerlSetVar QueueSize 300
-    
-    # how many simultanious file transfers
-    # before queueing (default: 10)
-    PerlSetVar MaxSends 10
-    
-    # Location of queue files (default: /tmp)
-    # This path must be writable by the Apache
-    # process
-    PerlSetVar QueuePath /tmp
-    
-    # Location of customized templates if needed
-    # Do not set this if you wish to use the internal templates
-    # Templates are process by Template-Toolkit, see
-    # http://www.template-toolkit.org for docs
-    #
-    # There are 4 template files needed.
-    #  queue_send.html     - The "Your download should start..." page
-    #  queue_sending.html  - Notifys the visitor of an existing download
-    #  queue_position.html - Page used while a user is inline
-    #  queue_full.html     - Tells the queue is full
-    # 
-    # View the defaults in the module for samples
-    PerlSetVar TemplatePath /usr/local/apache/templates
-    
-  </Directory>
+#httpd.conf
+<Directory "/usr/local/apache/htdocs/files">
+  SetHandler perl-script
+  PerlHandler Apache::Queue
+  
+  # the size of the queue (default: 300)
+  PerlSetVar QueueSize 300
+
+  # how many simultanious file transfers
+  # before queueing (default: 10)
+  PerlSetVar MaxSends 10
+
+  # Location of customized templates if needed
+  # Do not set this if you wish to use the internal templates
+  # Templates are process by Template-Toolkit, see
+  # http://www.template-toolkit.org for docs
+  #
+  # There are 4 template files needed.
+  #  queue_send.html     - The "Your download should start..." page
+  #  queue_sending.html  - Notifys the visitor of an existing download
+  #  queue_position.html - Page used while a user is inline
+  #  queue_full.html     - Tells the queue is full
+  # 
+  # View the defaults in the module for samples
+  PerlSetVar TemplatePath /usr/local/apache/templates
+
+</Directory>
 
 =head1 DESCRIPTION
 
